@@ -1,7 +1,7 @@
 /*
     This file is part of Choqok, the KDE micro-blogging client
 
-    Copyright (C) 2008-2010 Mehrdad Momeny <mehrdad.momeny@gmail.com>
+    Copyright (C) 2008-2011 Mehrdad Momeny <mehrdad.momeny@gmail.com>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
@@ -53,7 +53,9 @@
 #include <kstandarddirs.h>
 #include <KSplashScreen>
 #include <KMenu>
-#include <uploadmediadialog.h>
+#include "uploadmediadialog.h"
+#include <knotifyconfigwidget.h>
+#include <KMenuBar>
 
 MainWindow::MainWindow()
     : Choqok::UI::MainWindow(), quickWidget(0), s_settingsDialog(0), m_splash(0), microblogCounter(0)
@@ -62,23 +64,8 @@ MainWindow::MainWindow()
     setAttribute ( Qt::WA_DeleteOnClose, false );
     setAttribute ( Qt::WA_QuitOnClose, false );
 
-    connect(this, SIGNAL(updateTimelines()), SLOT(slotUpdateTimelines()));
-    if( Choqok::BehaviorSettings::showSplashScreen() ){
-        KStandardDirs *stdDirs = KGlobal::dirs();
-        QString img = stdDirs->findResource( "data", "choqok/images/splash_screen.png" );
-//         kDebug()<<img;
-        QPixmap splashpix( img );
-        if(splashpix.isNull())
-            kDebug()<<"Pixmap is NULL";
-        m_splash = new KSplashScreen( splashpix, Qt::WindowStaysOnTopHint );
-        m_splash->show();
-    }
-
     timelineTimer = new QTimer( this );
     setWindowTitle( i18n("Choqok") );
-    mainWidget = new KTabWidget( this );
-    mainWidget->setDocumentMode(true);
-    mainWidget->setMovable(true);
     connect( mainWidget, SIGNAL(currentChanged(int)), SLOT(slotCurrentBlogChanged(int)) );
     setCentralWidget( mainWidget );
 
@@ -108,14 +95,13 @@ MainWindow::MainWindow()
     QTimer::singleShot(0, Choqok::PluginManager::self(), SLOT( loadAllPlugins() ) );
 //     Choqok::AccountManager::self()->loadAllAccounts();
     QTimer::singleShot(0, Choqok::AccountManager::self(), SLOT( loadAllAccounts() ) );
-    
-    
+
+    connect(this, SIGNAL(updateTimelines()), SLOT(slotUpdateTimelines()));
 
     QPoint pos = Choqok::BehaviorSettings::position();
     if(pos.x() != -1 && pos.y() != -1) {
         move(pos);
     }
-
 }
 
 MainWindow::~MainWindow()
@@ -126,6 +112,18 @@ MainWindow::~MainWindow()
 void MainWindow::loadAllAccounts()
 {
     kDebug();
+
+    if( Choqok::BehaviorSettings::showSplashScreen() ){
+        KStandardDirs *stdDirs = KGlobal::dirs();
+        QString img = stdDirs->findResource( "data", "choqok/images/splash_screen.png" );
+        //         kDebug()<<img;
+        QPixmap splashpix( img );
+        if(splashpix.isNull())
+            kDebug()<<"Pixmap is NULL";
+        m_splash = new KSplashScreen( splashpix, Qt::WindowStaysOnTopHint );
+        m_splash->show();
+    }
+
     settingsChanged();
     QList<Choqok::Account*> accList = Choqok::AccountManager::self()->accounts();
     int count = microblogCounter = accList.count();
@@ -140,6 +138,7 @@ void MainWindow::loadAllAccounts()
         delete m_splash;
         m_splash = 0;
     }
+    ChoqokApplication::setStartingUp(false);
     createQuickPostDialog();
 }
 
@@ -217,9 +216,9 @@ void MainWindow::setupActions()
         showMain->setText( i18n("Restore") );
     connect( showMain, SIGNAL( triggered( bool ) ), this, SLOT( toggleMainWindow() ) );
 
-//     KAction *manageAccounts = new KAction(KIcon("user-group-properties"), i18n("Manage Accounts..."), this);
-//     actionCollection()->addAction(QLatin1String("manage_accounts"), manageAccounts);
-//     connect( manageAccounts, SIGNAL(triggered(bool)), this, SLOT(slotManageAccounts()) );
+    KAction *act = KStandardAction::configureNotifications ( this, SLOT ( slotConfNotifications() ),
+                                                             actionCollection() );
+    actionCollection()->addAction ( "settings_notifications", act );
 
     KAction *enableUpdates = new KAction( i18n( "Enable Update Timer" ), this );
     enableUpdates->setCheckable( true );
@@ -233,6 +232,12 @@ void MainWindow::setupActions()
     enableNotify->setShortcut( KShortcut( Qt::CTRL | Qt::Key_N ) );
     connect( enableNotify, SIGNAL( toggled( bool ) ), this, SLOT( setNotificationsEnabled( bool ) ) );
 
+    KAction* hideMenuBar = new KAction( i18n("Hide Menubar"), this );
+    hideMenuBar->setCheckable(true);
+    actionCollection()->addAction( QLatin1String( "choqok_hide_menubar" ), hideMenuBar );
+    hideMenuBar->setShortcut( KShortcut(Qt::ControlModifier | Qt::Key_M) );
+    connect( hideMenuBar, SIGNAL(toggled(bool)), menuBar(), SLOT(setHidden(bool)) );
+
     KAction *clearAvatarCache = new KAction(KIcon("edit-clear"), i18n( "Clear Avatar Cache" ), this );
     actionCollection()->addAction( QLatin1String( "choqok_clear_avatar_cache" ), clearAvatarCache );
     QString tip = i18n( "You have to restart Choqok to load avatars again" );
@@ -241,7 +246,7 @@ void MainWindow::setupActions()
     connect( clearAvatarCache, SIGNAL( triggered() ),
              Choqok::MediaManager::self(), SLOT(clearImageCache()) );
 
-    KAction *uploadMedium = new KAction( KIcon("arrow-up"), i18n( "Upload Medium" ), this );
+    KAction *uploadMedium = new KAction( KIcon("arrow-up"), i18n( "Upload Medium..." ), this );
     actionCollection()->addAction( QLatin1String( "choqok_upload_medium" ), uploadMedium );
     connect( uploadMedium, SIGNAL( triggered(bool)), this, SLOT(slotUploadMedium()) );
 
@@ -266,7 +271,7 @@ void MainWindow::setupActions()
 
 void MainWindow::slotConfNotifications()
 {
-//     KNotifyConfigWidget::configure ( this );
+    KNotifyConfigWidget::configure ( this );
 }
 
 void MainWindow::createQuickPostDialog()
@@ -311,7 +316,6 @@ void MainWindow::slotConfigChoqok()
 void MainWindow::settingsChanged()
 {
     kDebug();
-    ///TODO Check if there is any account and show a message if there isn't any!
     if ( Choqok::AccountManager::self()->accounts().count() < 1 ) {
         if ( KMessageBox::questionYesNo( this, i18n( "In order to use Choqok you need \
 an account at one of the supported micro-blogging services.\n\
@@ -528,6 +532,7 @@ void MainWindow::toggleMainWindow()
     else
         show();
 }
+
 void MainWindow::hideEvent(QHideEvent* event)
 {
     Choqok::UI::MainWindow::hideEvent(event);
@@ -554,8 +559,10 @@ void MainWindow::slotMarkAllAsRead()
 void MainWindow::slotCurrentBlogChanged(int)
 {
     Choqok::UI::MicroBlogWidget *wd = qobject_cast<Choqok::UI::MicroBlogWidget *>(mainWidget->currentWidget());
-    if( wd )
+    if( wd ) {
         wd->setFocus();
+        emit currentMicroBlogWidgetChanged(wd);
+    }
 }
 
 void MainWindow::oneMicroblogLoaded()
@@ -573,7 +580,8 @@ void MainWindow::oneMicroblogLoaded()
 
 void MainWindow::slotUpdateTimelines()
 {
-    showStatusMessage(i18n("Loading timelines..."));
+    if ( Choqok::AccountManager::self()->accounts().count() )
+         showStatusMessage( i18n( "Loading timelines..." ) );
 }
 
 void MainWindow::slotUploadMedium()
