@@ -1,7 +1,7 @@
 /*
 This file is part of Choqok, the KDE micro-blogging client
 
-Copyright (C) 2008-2010 Mehrdad Momeny <mehrdad.momeny@gmail.com>
+Copyright (C) 2008-2011 Mehrdad Momeny <mehrdad.momeny@gmail.com>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License as
@@ -51,11 +51,13 @@ along with this program; if not, see http://www.gnu.org/licenses/
 #include <notifymanager.h>
 #include "twitterapicomposerwidget.h"
 #include <QtOAuth/QtOAuth>
+#include <choqokappearancesettings.h>
+#include "application.h"
 
 class TwitterApiMicroBlog::Private
 {
 public:
-    Private():countOfTimelinesToSave(0), friendsPage(1)
+    Private():countOfTimelinesToSave(0), friendsCursor("-1")
     {
         monthes["Jan"] = 1;
         monthes["Feb"] = 2;
@@ -71,9 +73,8 @@ public:
         monthes["Dec"] = 12;
     }
     int countOfTimelinesToSave;
-    int friendsPage;
+    QString friendsCursor;
     QMap<QString, int> monthes;
-    QStringList friendsList;
     QJson::Parser parser;
 };
 
@@ -164,7 +165,7 @@ QMenu* TwitterApiMicroBlog::createActionsMenu(Choqok::Account* theAccount, QWidg
     menu->addAction(search);
 
     KAction *updateFriendsList = new KAction(KIcon("arrow-down"), i18n("Update Friends List"), menu);
-    search->setData( theAccount->alias() );
+    updateFriendsList->setData( theAccount->alias() );
     connect( updateFriendsList, SIGNAL(triggered(bool)), SLOT(slotUpdateFriendsList()) );
     menu->addAction(updateFriendsList);
 
@@ -174,21 +175,29 @@ QMenu* TwitterApiMicroBlog::createActionsMenu(Choqok::Account* theAccount, QWidg
 QList< Choqok::Post* > TwitterApiMicroBlog::loadTimeline( Choqok::Account *account,
                                                           const QString& timelineName)
 {
+    QList< Choqok::Post* > list;
+    if(timelineName.compare("Favorite") == 0)
+        return list;//NOTE Won't cache favorites, and this is for compatibility with older versions!
     kDebug()<<timelineName;
     QString fileName = Choqok::AccountManager::generatePostBackupFileName(account->alias(), timelineName);
     KConfig postsBackup( "choqok/" + fileName, KConfig::NoGlobals, "data" );
     QStringList tmpList = postsBackup.groupList();
-    QList<ChoqokId> groupList;
+
+/// to don't load old archives
+    if( tmpList.isEmpty() || !(QDateTime::fromString(tmpList.first()).isValid()) )
+        return list;
+///--------------
+
+    QList<QDateTime> groupList;
     foreach(const QString &str, tmpList)
-        groupList<<str;
+        groupList.append(QDateTime::fromString(str) );
     qSort(groupList);
-    QList< Choqok::Post* > list;
     int count = groupList.count();
     if( count ) {
         Choqok::Post *st = 0;
         for ( int i = 0; i < count; ++i ) {
             st = new Choqok::Post;
-            KConfigGroup grp( &postsBackup, groupList[i] );
+            KConfigGroup grp( &postsBackup, groupList[i].toString() );
             st->creationDateTime = grp.readEntry( "creationDateTime", QDateTime::currentDateTime() );
             st->postId = grp.readEntry( "postId", QString() );
             st->content = grp.readEntry( "text", QString() );
@@ -202,12 +211,14 @@ QList< Choqok::Post* > TwitterApiMicroBlog::loadTimeline( Choqok::Account *accou
             st->author.realName = grp.readEntry( "authorRealName", QString() );
             st->author.profileImageUrl = grp.readEntry( "authorProfileImageUrl", QString() );
             st->author.description = grp.readEntry( "authorDescription" , QString() );
+            st->author.isProtected = grp.readEntry("isProtected", false);
             st->isPrivate = grp.readEntry( "isPrivate" , false );
             st->author.location = grp.readEntry("authorLocation", QString());
             st->author.homePageUrl = grp.readEntry("authorUrl", QString());
             st->link = postUrl( account, st->author.userName, st->postId);
             st->isRead = grp.readEntry("isRead", true);
             st->repeatedFromUsername = grp.readEntry("repeatedFrom", QString());
+            st->repeatedPostId = grp.readEntry("repeatedPostId", QString());
 
             list.append( st );
         }
@@ -220,6 +231,8 @@ void TwitterApiMicroBlog::saveTimeline(Choqok::Account *account,
                                        const QString& timelineName,
                                        const QList< Choqok::UI::PostWidget* > &timeline)
 {
+    if(timelineName.compare("Favorite") == 0)
+        return;//NOTE Won't cache favorites, and this is for compatibility with older versions!
     kDebug();
     QString fileName = Choqok::AccountManager::generatePostBackupFileName(account->alias(), timelineName);
     KConfig postsBackup( "choqok/" + fileName, KConfig::NoGlobals, "data" );
@@ -235,7 +248,7 @@ void TwitterApiMicroBlog::saveTimeline(Choqok::Account *account,
     QList< Choqok::UI::PostWidget *>::const_iterator it, endIt = timeline.constEnd();
     for ( it = timeline.constBegin(); it != endIt; ++it ) {
         const Choqok::Post *post = &((*it)->currentPost());
-        KConfigGroup grp( &postsBackup, post->postId );
+        KConfigGroup grp( &postsBackup, post->creationDateTime.toString() );
         grp.writeEntry( "creationDateTime", post->creationDateTime );
         grp.writeEntry( "postId", post->postId.toString() );
         grp.writeEntry( "text", post->content );
@@ -251,14 +264,18 @@ void TwitterApiMicroBlog::saveTimeline(Choqok::Account *account,
         grp.writeEntry( "authorDescription" , post->author.description );
         grp.writeEntry( "isPrivate" , post->isPrivate );
         grp.writeEntry( "authorLocation" , post->author.location );
+        grp.writeEntry( "isProtected" , post->author.isProtected );
         grp.writeEntry( "authorUrl" , post->author.homePageUrl );
         grp.writeEntry( "isRead" , post->isRead );
         grp.writeEntry( "repeatedFrom", post->repeatedFromUsername);
+        grp.writeEntry( "repeatedPostId", post->repeatedPostId.toString());
     }
     postsBackup.sync();
-    --d->countOfTimelinesToSave;
-    if(d->countOfTimelinesToSave < 1)
-        emit readyForUnload();
+    if(Choqok::Application::isShuttingDown()) {
+        --d->countOfTimelinesToSave;
+        if(d->countOfTimelinesToSave < 1)
+            emit readyForUnload();
+    }
 }
 
 Choqok::UI::ComposerWidget* TwitterApiMicroBlog::createComposerWidget(Choqok::Account* account, QWidget* parent)
@@ -652,35 +669,34 @@ void TwitterApiMicroBlog::slotRemoveFavorite ( KJob *job )
 
 void TwitterApiMicroBlog::listFriendsUsername(TwitterApiAccount* theAccount)
 {
-    d->friendsList.clear();
+    friendsList.clear();
     if ( theAccount ) {
         requestFriendsScreenName(theAccount);
     }
 }
 
-void TwitterApiMicroBlog::requestFriendsScreenName(TwitterApiAccount* theAccount, int page)
+void TwitterApiMicroBlog::requestFriendsScreenName(TwitterApiAccount* theAccount)
 {
     kDebug();
     TwitterApiAccount* account = qobject_cast<TwitterApiAccount*>(theAccount);
     KUrl url = account->apiUrl();
-    url.addPath( QString("/statuses/friends/%1.%2").arg(theAccount->username()).
-                                                    arg(format));
+    url.addPath( QString("/statuses/friends.xml") );
+    KUrl tmpUrl(url);
+    url.addQueryItem( "cursor", d->friendsCursor );
     QOAuth::ParamMap params;
-    if(account->usingOAuth()){
-        params.insert( "page", QByteArray::number( page ) );
-    } else {
-        url.addQueryItem( "page", QString::number( page ) );
-    }
+    params.insert("cursor", d->friendsCursor.toLatin1());
 
     KIO::StoredTransferJob *job = KIO::storedGet( url, KIO::Reload, KIO::HideProgressInfo ) ;
     if ( !job ) {
         kDebug() << "Cannot create an http GET request!";
         return;
     }
-    job->addMetaData("customHTTPHeader", "Authorization: " + authorizationHeader(account, url, QOAuth::GET, params));
+    job->addMetaData("customHTTPHeader", "Authorization: " + authorizationHeader(account, tmpUrl,
+                                                                                 QOAuth::GET, params));
     mJobsAccount[job] = theAccount;
     connect( job, SIGNAL( result( KJob* ) ), this, SLOT( slotRequestFriendsScreenName(KJob*) ) );
     job->start();
+    Choqok::UI::Global::mainWindow()->showStatusMessage( i18n("Updating friends list for account %1 ...", theAccount->username()) );
 }
 
 void TwitterApiMicroBlog::slotRequestFriendsScreenName(KJob* job)
@@ -688,19 +704,22 @@ void TwitterApiMicroBlog::slotRequestFriendsScreenName(KJob* job)
     kDebug();
     TwitterApiAccount *theAccount = qobject_cast<TwitterApiAccount *>( mJobsAccount.take(job) );
     KIO::StoredTransferJob* stJob = qobject_cast<KIO::StoredTransferJob*>( job );
-    QStringList newList;
-    if(format=="json"){
-        newList = readUsersScreenNameFromJson( theAccount, stJob->data() );
-    } else {
-        newList = readUsersScreenNameFromXml( theAccount, stJob->data() );
+    if (stJob->error()) {
+        emit error(theAccount, ServerError, i18n("Friends list for account %1 could not be updated:\n%2",
+            theAccount->username(), stJob->errorString()), Critical);
+        return;
     }
-    d->friendsList << newList;
+    QStringList newList;
+    newList = readUsersScreenNameFromXml( theAccount, stJob->data() );
+    friendsList << newList;
     if ( newList.count() == 100 ) {
-        requestFriendsScreenName( theAccount, ++d->friendsPage );
+        requestFriendsScreenName( theAccount );
     } else {
-        d->friendsList.removeDuplicates();
-        theAccount->setFriendsList(d->friendsList);
-        emit friendsUsernameListed( theAccount, d->friendsList );
+        friendsList.removeDuplicates();
+        theAccount->setFriendsList(friendsList);
+        Choqok::UI::Global::mainWindow()->showStatusMessage(i18n("Friends list for account %1 has been updated.",
+            theAccount->username()) );
+        emit friendsUsernameListed( theAccount, friendsList );
     }
 }
 
@@ -747,7 +766,7 @@ void TwitterApiMicroBlog::requestTimeLine ( Choqok::Account* theAccount, QString
     if ( page ) {
         url.addQueryItem ( "page", QString::number ( page ) );
     }
-    kDebug() << "Latest " << type << " Id: " << latestStatusId;
+    kDebug() << "Latest " << type << " Id: " << latestStatusId;// << " apiReq: " << url;
 
     KIO::StoredTransferJob *job = KIO::storedGet ( url, KIO::Reload, KIO::HideProgressInfo ) ;
     if ( !job ) {
@@ -894,6 +913,10 @@ Choqok::Post* TwitterApiMicroBlog::readPostFromDomNode(Choqok::Account* theAccou
                     post->author.realName = elm3.text();
                 } else if ( elm3.tagName() == QString ( "description" ) ) {
                     post->author.description = elm3.text();
+                } else if ( elm3.tagName() == "statusnet:profile_url" ) {
+                    post->author.homePageUrl = elm3.text();
+                } else if ( elm3.tagName() == "protected" ) {
+                    post->author.isProtected = elm3.text().contains("true") ? true : false;
                 }
                 node3 = node3.nextSibling();
             }
@@ -903,7 +926,7 @@ Choqok::Post* TwitterApiMicroBlog::readPostFromDomNode(Choqok::Account* theAccou
         node = node.nextSibling();
     }
     if(repeatedPost){
-        post->setRepeatedOf(repeatedPost);
+        setRepeatedOfInfo(post,repeatedPost);
         delete repeatedPost;
     }
     post->link = postUrl(theAccount, post->author.userName, post->postId);
@@ -1069,7 +1092,7 @@ QStringList TwitterApiMicroBlog::readUsersScreenNameFromXml( Choqok::Account* th
     document.setContent( buffer );
     QDomElement root = document.documentElement();
 
-    if ( root.tagName() != "users" ) {
+    if ( root.tagName() != "users_list" ) {
         QString err = checkXmlForError(buffer);
         if(!err.isEmpty()){
             emit error(theAccount, ServerError, err, Critical);
@@ -1081,26 +1104,54 @@ QStringList TwitterApiMicroBlog::readUsersScreenNameFromXml( Choqok::Account* th
         }
         return list;
     }
-    QDomNode node = root.firstChild();
-    QString timeStr;
-    while ( !node.isNull() ) {
-        if ( node.toElement().tagName() != "user" ) {
-            kDebug() << "there's no user tag in XML!\n"<<buffer;
-            return list;
-        }
-        QDomNode node2 = node.firstChild();
-        while ( !node2.isNull() ) {
-            if ( node2.toElement().tagName() == "screen_name" ) {
-                list.append( node2.toElement().text() );
-                break;
+    QDomNode section = root.firstChild();
+    QDomNode node = section.firstChild();
+    while ( !section.isNull() ) {
+        if ( section.toElement().tagName() == "users" ) {
+            while ( !node.isNull() ) {
+                if ( node.toElement().tagName() != "user" ) {
+                    kDebug() << "there's no user tag in XML!\n"<<buffer;
+                    return list;
+                }
+                QDomNode node2 = node.firstChild();
+                while ( !node2.isNull() ) {
+                    if ( node2.toElement().tagName() == "screen_name" ) {
+                        list.append( node2.toElement().text() );
+                        break;
+                    }
+                    node2 = node2.nextSibling();
+                }
+                node = node.nextSibling();
             }
-            node2 = node2.nextSibling();
+        } else if ( section.toElement().tagName() == "next_cursor" ) {
+            d->friendsCursor = section.toElement().text();
         }
-        node = node.nextSibling();
+        section = section.nextSibling();
     }
     return list;
 }
 
+void TwitterApiMicroBlog::setRepeatedOfInfo(Choqok::Post* post, Choqok::Post* repeatedPost)
+{
+    if( Choqok::AppearanceSettings::showRetweetsInChoqokWay() ) {
+        post->content = repeatedPost->content;
+        post->replyToPostId = repeatedPost->replyToPostId;
+        post->replyToUserId = repeatedPost->replyToUserId;
+        post->replyToUserName = repeatedPost->replyToUserName;
+        post->repeatedFromUsername = repeatedPost->author.userName;
+        post->repeatedPostId = repeatedPost->postId;
+    } else {
+        post->content = repeatedPost->content;
+        post->replyToPostId = repeatedPost->replyToPostId;
+        post->replyToUserId = repeatedPost->replyToUserId;
+        post->replyToUserName = repeatedPost->replyToUserName;
+        post->repeatedFromUsername = post->author.userName;
+        post->author = repeatedPost->author;
+        post->repeatedPostId = repeatedPost->postId;
+    }
+    post->creationDateTime = repeatedPost->creationDateTime;
+}
+
 QDateTime TwitterApiMicroBlog::dateFromString ( const QString &date )
 {
     char s[10];
@@ -1396,6 +1447,11 @@ QString TwitterApiMicroBlog::checkXmlForError(const QByteArray& buffer)
 
 ///===================================================================
 
+QJson::Parser* TwitterApiMicroBlog::jsonParser()
+{
+    return &d->parser;
+}
+
 QString TwitterApiMicroBlog::checkJsonForError(const QByteArray& buffer)
 {
     bool ok;
@@ -1476,11 +1532,12 @@ Choqok::Post* TwitterApiMicroBlog::readPostFromJsonMap(Choqok::Account* theAccou
     post->author.userId = userMap["id"].toString();
     post->author.userName = userMap["screen_name"].toString();
     post->author.profileImageUrl = userMap["profile_image_url"].toString();
+    post->author.homePageUrl = userMap["statusnet_profile_url"].toString();
     Choqok::Post* repeatedPost = 0;
     QVariantMap retweetedMap = var["retweeted_status"].toMap();
     if( !retweetedMap.isEmpty() ){
         repeatedPost = readPostFromJsonMap( theAccount, retweetedMap, new Choqok::Post);
-        post->setRepeatedOf(repeatedPost);
+        setRepeatedOfInfo(post, repeatedPost);
         delete repeatedPost;
     }
     post->link = postUrl(theAccount, post->author.userName, post->postId);
@@ -1602,4 +1659,20 @@ QStringList TwitterApiMicroBlog::readUsersScreenNameFromJson(Choqok::Account* th
     return list;
 }
 
+Choqok::User TwitterApiMicroBlog::readUserFromJsonMap(Choqok::Account* theAccount, const QVariantMap& map)
+{
+    Q_UNUSED(theAccount);
+    Choqok::User u;
+    u.description = map["description"].toString();
+    u.followersCount = map["followers_count"].toUInt();
+    u.homePageUrl = map["url"].toString();
+    u.isProtected = map["protected"].toBool();
+    u.location = map["location"].toString();
+    u.profileImageUrl = map["profile_image_url"].toString();
+    u.realName = map["name"].toString();
+    u.userId = map["id"].toString();
+    u.userName = map["screen_name"].toString();
+    return u;
+}
+
 #include "twitterapimicroblog.moc"
