@@ -1,7 +1,7 @@
 /*
 This file is part of Choqok, the KDE micro-blogging client
 
-Copyright (C) 2008-2010 Mehrdad Momeny <mehrdad.momeny@gmail.com>
+Copyright (C) 2008-2011 Mehrdad Momeny <mehrdad.momeny@gmail.com>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License as
@@ -20,14 +20,18 @@ GNU General Public License for more details.
 You should have received a copy of the GNU General Public License
 along with this program; if not, see http://www.gnu.org/licenses/
 */
-#ifndef TWITTERAPIMICROBLOGPLUGIN_H
-#define TWITTERAPIMICROBLOGPLUGIN_H
+#ifndef TWITTERAPIMICROBLOG_H
+#define TWITTERAPIMICROBLOG_H
 
-#include "microblog.h"
-#include <KUrl>
-#include "twitterapisearch.h"
 #include <QtXml/QDomElement>
 #include <QtOAuth/qoauth_namespace.h>
+#include <KDE/KUrl>
+#include <microblog.h>
+#include "twitterapisearch.h"
+
+namespace QJson {
+class Parser;
+}
 
 namespace QOAuth {
 class Interface;
@@ -143,8 +147,20 @@ public:
 
     QDateTime dateFromString( const QString &date );
 
+    /**
+     * The text to add under repeated posts, to notice user about it.
+     */
     virtual QString generateRepeatedByUserTooltip( const QString &username )=0;
 
+    /**
+     * The question will show to confirm repeat post.
+     */
+    virtual QString repeatQuestion() = 0;
+
+    virtual QByteArray authorizationHeader( TwitterApiAccount* theAccount,
+                                            const KUrl &requestUrl, QOAuth::HttpMethod method,
+                                            QOAuth::ParamMap params = QOAuth::ParamMap());
+
 public Q_SLOTS:
     /**
     Launch a dialog to send direct message.
@@ -173,7 +189,7 @@ protected Q_SLOTS:
     virtual void slotCreateFavorite( KJob *job );
     virtual void slotRemoveFavorite( KJob *job );
     virtual void slotRequestTimeline( KJob *job );
-    virtual void requestFriendsScreenName( TwitterApiAccount* theAccount, int page = 1 );
+    virtual void requestFriendsScreenName( TwitterApiAccount* theAccount );
     virtual void slotRequestFriendsScreenName( KJob *job );
     virtual void slotCreateFriendship( KJob *job );
     virtual void slotDestroyFriendship( KJob *job );
@@ -191,9 +207,7 @@ protected:
 
     virtual void setTimelineInfos();
 
-    virtual QByteArray authorizationHeader( TwitterApiAccount* theAccount,
-                                            const KUrl &requestUrl, QOAuth::HttpMethod method,
-                                            QOAuth::ParamMap params = QOAuth::ParamMap());
+    void setRepeatedOfInfo(Choqok::Post* post, Choqok::Post* repeatedPost);
 
     ///==============================================
     /// XML:
@@ -219,6 +233,7 @@ protected:
     /// JSON:
     ///===============================================
 
+    QJson::Parser *jsonParser();
     virtual Choqok::Post * readPostFromJsonMap( Choqok::Account* theAccount,
                                                    const QVariantMap& var, Choqok::Post* post );
     virtual Choqok::Post * readPostFromJson( Choqok::Account* theAccount,
@@ -229,7 +244,7 @@ protected:
     virtual QList<Choqok::Post*> readDMessagesFromJson(Choqok::Account *theAccount, const QByteArray &buffer );
     virtual QStringList readUsersScreenNameFromJson( Choqok::Account *theAccount, const QByteArray & buffer );
     virtual Choqok::User *readUserInfoFromJson( const QByteArray &buffer );
-
+    virtual Choqok::User readUserFromJsonMap( Choqok::Account* theAccount, const QVariantMap& map );
     /**
     Checks xml returned from server for error, and return error string, Or an empty string if nothing found!
     */
@@ -252,6 +267,7 @@ protected:
     QMap<KJob*, Choqok::Account*> mJobsAccount;
     QMap<KJob*, QString> mFriendshipMap;
     QString format;
+    QStringList friendsList;
 
 private:
     class Private;
